<?php

namespace WCFAddonsPro\Extensions;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if(!class_exists('\WCFAddonsPro\Base\Animation_Builder')){
	include_once WCF_ADDONS_PRO_PATH. 'inc/core/animation-editor.php';
}

if(!class_exists('\WCFAddonsPro\Base\Animation_Builder_Page_Type')){
	include_once WCF_ADDONS_PRO_PATH. 'inc/core/anim-builder-page-type.php';
}

Class Animation_Builder
{

   	/**
	 * Instance
	 *
	 * @since 1.0.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $instance = null;
    public $page_type = null;
	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @return Plugin An instance of the class.
	 * @since 1.2.0
	 * @access public
	 */
	public static function instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	} 
	
	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function __construct() {	
		
		add_action( 'admin_bar_menu', [ $this,'button_interface' ] , 500);			
		add_action( 'init', [ $this , 'custom_rewrite_rules' ]);
		add_filter( 'query_vars', [$this ,'custom_query_vars'] );
		add_action( 'template_redirect', [ $this , 'animation_builder_template_redirect' ]);
		add_action( 'wp_enqueue_scripts', [$this,'config_enqueue_script'] );
		add_action( 'wp_footer', [$this ,'html_selector'] );
		add_action( 'wp_ajax_wcf_anim_builder_configs_store', [ $this ,'configs_store' ] );
		add_action( 'wp_ajax_wcf_anim_builder_configs_delete', [ $this ,'configs_delete' ] );
		//editor 
		$this->page_type = \WCFAddonsPro\Base\Animation_Builder_Page_Type::instance();
		$builder = \WCFAddonsPro\Base\Animation_Builder::instance();
		$builder->setPageType($this->page_type);
	}
	
	public function configs_store() {
		// Verify nonce
		check_ajax_referer('wcf-admin-preview-nonce', 'wcf_nonce');
	
		// Check user permissions
		if (!current_user_can('manage_options')) {
			wp_send_json_error(['msg' => esc_html__('Unauthorized access', 'wcf-addons-pro')], 403);
		}
	
		// Get and sanitize the JSON data
		$pageTypeConfigs = isset($_POST['pageTypeConfigs']) ? wp_unslash($_POST['pageTypeConfigs']) : '';
		$animationConfigs = isset($_POST['animationConfigs']) ? wp_unslash($_POST['animationConfigs']) : '';
	
		// Validate JSON structure
		if (empty($pageTypeConfigs) || empty($animationConfigs)) {
			wp_send_json_error(['msg' => esc_html__('Missing configuration data', 'wcf-addons-pro')], 400);
		}
	
		// Decode JSON and check for errors
		$pageTypeConfigs = json_decode($pageTypeConfigs, true);
		$animationConfigs = json_decode($animationConfigs, true);
	
		if (json_last_error() !== JSON_ERROR_NONE) {
			wp_send_json_error(['msg' => esc_html__('Invalid JSON format', 'wcf-addons-pro')], 400);
		}
	
		// Further validation on the decoded data to ensure expected structure
		if (!is_array($pageTypeConfigs) || !is_array($animationConfigs)) {
			wp_send_json_error(['msg' => esc_html__('Invalid configuration structure', 'wcf-addons-pro')], 400);
		}	
		
	
		// Save configurations
		$this->page_type->saveConfig($pageTypeConfigs, $animationConfigs);
		wp_send_json_success(['msg' => esc_html__('Configurations updated successfully', 'wcf-addons-pro'), 'configs' => $animationConfigs]);
	}	
	public function configs_delete() {
		// Verify nonce
		check_ajax_referer('wcf-admin-preview-nonce', 'wcf_nonce');
	
		// Check user permissions
		if (!current_user_can('manage_options')) {
			wp_send_json_error(['msg' => esc_html__('Unauthorized access', 'wcf-addons-pro')], 403);
		}
	
		// Get and sanitize the JSON data
		$pageTypeConfigs = isset($_POST['pageTypeConfigs']) ? wp_unslash($_POST['pageTypeConfigs']) : '';
	
		// Validate JSON structure
		if (empty($pageTypeConfigs)) {
			wp_send_json_error(['msg' => esc_html__('Missing configuration data', 'wcf-addons-pro')], 400);
		}
	
		// Decode JSON and check for errors
		$pageTypeConfigs = json_decode($pageTypeConfigs, true);
	
		if (json_last_error() !== JSON_ERROR_NONE) {
			wp_send_json_error(['msg' => esc_html__('Invalid JSON format', 'wcf-addons-pro')], 400);
		}
	
		// Further validation on the decoded data
		if (!is_array($pageTypeConfigs)) {
			wp_send_json_error(['msg' => esc_html__('Invalid configuration structure', 'wcf-addons-pro')], 400);
		}
			
	
		// Delete configurations
		$this->page_type->deleteConfig($pageTypeConfigs);
		wp_send_json_success(['msg' => esc_html__('Configurations deleted successfully', 'wcf-addons-pro')]);
	}	
	
	public function config_enqueue_script(){	
		
		if(isset($_GET['action']) && $_GET['action'] == 'animation-builder'){
			wp_enqueue_script('wcf-animation-builder-preview');
			wp_localize_script( 'wcf-animation-builder-preview', 'wcf_anim_preview_object',
				array( 
					'ajaxurl' => admin_url( 'admin-ajax.php' ),		
					'type' => 'wcf-animation-builder',
					'nonce'      => wp_create_nonce( 'wcf-admin-preview-nonce' ),
					'animation_config' => is_array($this->page_type->getConfig()) ? $this->page_type->getConfig(): []  ,
					'pageTypeConfigs' => $this->page_type->getCurrentPageType()
				)
			);
		}
		
	}
	
	public function register_editor_scripts() {
	
		$animation_builder = get_query_var('wcf_animation_builder');
		
		if ($animation_builder)
		{			
			// Safely include the template only once
			$template_path = WCF_ADDONS_PRO_PATH . 'templates/animation-builder-template.php';
			if (file_exists($template_path)) {				
				do_action('wcf/animation/builder/head/enqueue');
			}
		}
		
	}

	
	function custom_rewrite_rules() {
		
		add_rewrite_rule(
			'^wcf-animation-builder/([^/]*)/?$', // Regex to match `wcf-animation-builder/something`
			'index.php?wcf_animation_builder=$matches[1]', // Query variable for `something`
			'top'
		);
		
	}

	function custom_query_vars($vars) {
		$vars[] = 'wcf_animation_builder'; // Add your query variable
		return $vars;
	}
	
	function animation_builder_template_redirect() {
	
		if (is_admin()) {
			return; // Do nothing in the admin area
		}
	
		$animation_builder = get_query_var('wcf_animation_builder');
		if ($animation_builder) {		
			// Safely include the template only once
			$template_path = WCF_ADDONS_PRO_PATH . 'templates/animation-builder-template.php';
			if (file_exists($template_path)) {
				include_once $template_path;
			} else {
				// Optional: Handle the case where the template file is missing
				wp_die('Template file not found!');
			}
			exit; // Prevent WordPress from loading other templates
		}
	}
	function wp_get_current_url() {
	
		$scheme = is_ssl() ? 'https' : 'http'; // Check if the site is using HTTPS
		$host = $_SERVER['HTTP_HOST'];         // Get the domain name
		$request_uri = $_SERVER['REQUEST_URI']; // Get the path and query string
		return esc_url("{$scheme}://{$host}{$request_uri}");
	}
	public function html_selector(){
		
		if(isset($_GET['action']) && $_GET['action'] == 'animation-builder'){
			?>
			     <style>
				    /* Highlight hovered element */
				    .wcf-animb--hover-highlight {
				      outline: 2px solid red;
				    }
				
				    /* Popup styles */
				    .wcfanimb-popup {
						position: fixed;
					    background: #250a0a;
					    padding: 15px;
					    border: 1px solid #200f0f;
					    border-radius: 4px;
					    font-family: Arial, sans-serif;
					    box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
					    z-index: 1000;
					    display: flex !important;
					    justify-content: center;
					    align-items: start;
					    flex-direction: column;
					    gap: 20px;
					    max-width: 600px;
					    color: #fff;
				    }
				
				    .wcfanimb-popup button {
				      margin-top: 5px;
				      display: block;
				      width: 100%;
				      max-width: 250px;
				      padding: 5px;
				      background-color: hsl(11 97% 64%);
				      color: white;
				      border: none;
				      border-radius: 4px;
				      cursor: pointer;
				    }
				
				    .wcfanimb-popup button:hover {
				      background-color: hsl(11 97% 50%);
				    }
				  </style>
				<div id="wcfanim-selectorPopup" class="wcfanimb-popup" style="display: none;">
				    <div id="wcfanim-popupContent" class="wcfanimb-popupContent" ></div>
				    <button id="wcfanim-copySelector">Copy Selector</button>
				</div>
			<?php
		}
		
	}
	public function button_interface($wp_admin_bar){
	
		if(is_admin()){
			return;
		}
	
		
		$animation_builder_url = home_url('/wcf-animation-builder/editor/');		
		$editor_url = apply_filters('wcf/animation/builder/admin/bar/url', add_query_arg( array(
			'builder_url' => $this->wp_get_current_url(),			
		), $animation_builder_url));
	
		if (current_user_can('administrator')) {
			$args = array(
				'id'    => 'wcf--admin--animation--builder--button', // Unique ID for the button
				'title' => '<svg width="18" height="18" viewBox="0 0 18 18" fill="none" xmlns="http://www.w3.org/2000/svg">
						<path d="M7.9608 13.3467L8.619 11.8391C9.20482 10.4975 10.2592 9.42945 11.5744 8.84565L13.3861 8.04143C13.9621 7.78575 13.9621 6.94776 13.3861 6.69208L11.6309 5.91296C10.2819 5.31414 9.20865 4.20661 8.63287 2.81921L7.96612 1.21255C7.7187 0.616324 6.89489 0.616326 6.64747 1.21255L5.9807 2.81919C5.40493 4.20661 4.33165 5.31414 2.98264 5.91296L1.22743 6.69208C0.651402 6.94776 0.651402 7.78575 1.22743 8.04143L3.03922 8.84565C4.35442 9.42945 5.40878 10.4975 5.99456 11.8391L6.6528 13.3467C6.90582 13.9262 7.70775 13.9262 7.9608 13.3467ZM14.551 17.0174L14.7361 16.5932C15.0661 15.8367 15.6605 15.2344 16.4021 14.9049L16.9724 14.6515C17.2809 14.5145 17.2809 14.0662 16.9724 13.9292L16.4341 13.6899C15.6733 13.352 15.0683 12.7274 14.7439 11.9452L14.5539 11.4867C14.4214 11.1672 13.9796 11.1672 13.8471 11.4867L13.657 11.9452C13.3327 12.7274 12.7277 13.352 11.967 13.6899L11.4286 13.9292C11.1202 14.0662 11.1202 14.5145 11.4286 14.6515L11.9989 14.9049C12.7405 15.2344 13.3348 15.8367 13.6648 16.5932L13.85 17.0174C13.9855 17.328 14.4155 17.328 14.551 17.0174Z" fill="white"/>
						</svg>'.esc_html__('Custom Animation', 'wcf-addons-pro'),  
				'parent' => 'top-secondary',
				'href'  => esc_url( $editor_url ),  // The URL the button should link to
				'meta'  => array(
					'class' => 'wcf--admin--animation--builder--button',
					'onclick' => '' // JavaScript action
				),
			);
		
			$wp_admin_bar->add_node( $args );
		}
	}
	
}

Animation_Builder::instance();