(function (wcfWindow) {
  "use strict";

  const wcfAnimBPreview = (function () {
  
        let config = {};
        let hoverEnabled = false; 
        function logDebug(message) {
          if (config.debug) {
            console.log(`[DEBUG]: ${message}`);
          }
        }
    
        function getFullSelector(element) {
          const path = [];
          let depth = 0; // Track depth
          let idCount = 0; // Track the number of IDs in the selector
        
          while (element && element.tagName.toLowerCase() !== "html" && depth < 3) {
            let selector = getUniqueSelector(element);
        
            // Check if the current element has an ID
            if (element.id) {
              idCount++;
              // Stop adding IDs if the limit is reached
              if (idCount > 2) {
                break;
              }
            }
        
            path.unshift(selector);
            element = element.parentElement;
            depth++; // Increment depth
          }
        
          return path.join(" > ");
        }
        
        function getUniqueSelector(element) {
          const tag = element.tagName.toLowerCase();
        
          // Add ID if available
          if (element.id) {
            return `${tag}#${element.id}`; // Only tag and ID, skip classes
          }
        
          // Add class names, excluding the hover-highlight class
          const classList = Array.from(element.classList).filter(
            (cls) => cls !== "wcf-animb--hover-highlight"
          );
        
          if (classList.length > 0) {
            return `${tag}.${classList.join(".")}`; // Concatenated classes if no ID
          }
        
          return tag; // Return only tag if no ID or classes
        }
            
        // Show the popup near the clicked element
        function showPopup(selector, x, y) {
          const popup = document.getElementById("wcfanim-selectorPopup");
          const content = document.getElementById("wcfanim-popupContent");
        
          content.textContent = selector;
          popup.style.left = `${x}px`;
          popup.style.top = `${y}px`;
          popup.style.display = "block";
        }
        
        // Hide the popup
        function hidePopup() {
          const popup = document.getElementById("wcfanim-selectorPopup");
          popup.style.display = "none";
        }
   
        function handleMouseOver(event) {
          const target = event.target;    
          if(target.classList.contains('wcfanimb-popup')){
            return;
          }
          if(target.classList.contains('wcfanimb-popupContent')){
            return;
          }
          target.classList.add("wcf-animb--hover-highlight");  
          target.addEventListener("mouseleave", () => {
            target.classList.remove("wcf-animb--hover-highlight");
          }, { once: true });
        }
        
        function enableHover() {
          if (!hoverEnabled) {
            document.body.addEventListener("mouseover", handleMouseOver);
            hoverEnabled = true;     
          }
        }
    
        function disableHover() {
          if (hoverEnabled) {
            document.body.removeEventListener("mouseover", handleMouseOver);
            hoverEnabled = false;   
          }
        }   
   
        return {
          // Get the current configuration
          getConfig: function (key) {
            return key ? config[key] : { ...config }; // Return specific key or full config
          },
    
          // Set a single configuration or multiple configurations
          setConfig: function (key, value) {
            if (typeof key === "object") {
              // Update multiple configurations
              Object.assign(config, key);
            } else {
              // Update a single configuration
              config[key] = value;
            }
            logDebug(`Configuration updated: ${key}`);
          },
    
          // Show a message using the current configurations
          playAnimation: function () {
            console.log(config);
          },
          sendPageConfig: function () {
          
            window.addEventListener(
              "message",
              (event) => {
                if ("wcf-animation-config" in event.data) {
                  wcfAnimBPreview.setConfig(
                    "animation",
                    event.data["wcf-animation-config"]
                  ); // Update multiple configs
                  wcfAnimBPreview.playAnimation();
                }
              },
              false
            );
          
            setTimeout(() => {
              window.parent.postMessage(wcf_anim_preview_object);
            }, 1000);
          },
          enableHoverSelector: function () {
            enableHover();
          },
          disableHoverSelector: function () {
            disableHover();
          },
          
          runPopup: function () {
            document.body.addEventListener("click", (event) => {
              event.preventDefault();        
              
              const target = event.target;
              const selector = getFullSelector(target); 
            
              // Show the popup at the click location
              showPopup(selector, event.clientX + 10, event.clientY + 10);
            });
            /// Copy
            document.getElementById("wcfanim-copySelector").addEventListener("click", () => {
              const selectorText = document.getElementById("wcfanim-popupContent").textContent;
              navigator.clipboard.writeText(selectorText).then(() => {
                disableHover();
                hidePopup();
              });
            });
          },
        };
        
  })();
  
  wcfAnimBPreview.enableHoverSelector();
  wcfAnimBPreview.runPopup(); 
  wcfAnimBPreview.sendPageConfig(); 
})(window);
