import { IconPlus2 } from "@/lib/icons";
import { Button } from "../ui/button";
import EditorBody from "./EditorBody";
import EditorFooter from "./EditorFooter";
import EditorHeader from "./EditorHeader";
import { useAnimationControl, useContentStep } from "@/hooks/app.hooks";
import { ScrollArea } from "../ui/scroll-area";
import { ABPresetData } from "@/config/animationPresetData";
import { generateUniqueId } from "../../../../utils/generateUniqueId";

const MainEditor = () => {
  const { contentStep, setContentStep } = useContentStep();
  const { createAnimation, allAnimation } = useAnimationControl();
  return (
    <div className="bg-background h-full flex flex-col justify-between">
      <EditorHeader />
      {contentStep.step === 1 && (
        <div className="p-3 border-b border-border">
          <Button
            variant="play"
            size="play"
            onClick={() => {
              const sampleData = {
                ...ABPresetData,
                id: generateUniqueId(),
                title:
                  ABPresetData.title +
                  (allAnimation.length ? "_" + (allAnimation.length + 1) : ""),
              };
              setContentStep({
                step: 2,
                data: sampleData,
              });
              createAnimation(sampleData);
            }}
          >
            <IconPlus2 /> Add new animation
          </Button>
        </div>
      )}

      <div className="flex-1">
        <ScrollArea className="h-[83vh]">
          <EditorBody contentStep={contentStep} />
        </ScrollArea>
      </div>
      <EditorFooter />
    </div>
  );
};

export default MainEditor;
