import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";
import { InputWithShape } from "@/components/ui/input-with-shape";
import { Button } from "@/components/ui/button";
import {
  Select,
  SelectContent,
  SelectGroup,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { IconDelete, IconPlus, IconPlus2 } from "@/lib/icons";
import { Input } from "../ui/input";
import { ScrollArea } from "@/components/ui/scroll-area";

const easeConfig = [
  "power2.out",
  "power2.in",
  "power2.inOut",
  "power3.out",
  "power3.in",
  "power3.inOut",
  "power4.out",
  "power4.in",
  "power4.inOut",
  "back",
  "bounce",
  "circ",
  "elastic",
  "expo",
  "sine",
  "steps",
  "rough",
  "slow",
];

const PropertiesControl = ({
  properties,
  selectedProperties,
  addProperties,
  updateProperties,
  deleteProperties,
}) => {
  const generateField = (item) => {
    if (item.type === "boolean") {
      return (
        <Select
          value={item.value}
          onValueChange={(value) => updateProperties(value, item)}
        >
          <SelectTrigger className="min-w-[90px]">
            <SelectValue placeholder="Option" className="line-clamp-1" />
          </SelectTrigger>
          <SelectContent className="min-w-[90px]">
            <SelectGroup>
              <SelectItem value={"true"}>True</SelectItem>
              <SelectItem value={"false"}>False</SelectItem>
            </SelectGroup>
          </SelectContent>
        </Select>
      );
    } else if (item.type === "number") {
      if (item?.unit === "s") {
        return (
          <InputWithShape
            value={item?.value}
            onChange={(e) => updateProperties(e.target.value, item)}
            placeholder="add value"
          />
        );
      } else {
        return (
          <Input
            value={item?.value}
            type="number"
            onChange={(e) => updateProperties(e.target.value, item)}
            placeholder="add value"
            className="no-spinner"
          />
        );
      }
    } else if (item.type === "string") {
      return (
        <Input
          value={item?.value}
          onChange={(e) => updateProperties(e.target.value, item)}
          placeholder="add value"
        />
      );
    } else if (item.type === "ease") {
      return (
        <Select
          value={item.value}
          onValueChange={(value) => updateProperties(value, item)}
        >
          <SelectTrigger className="min-w-[90px]">
            <SelectValue placeholder="Option" />
          </SelectTrigger>
          <SelectContent className="min-w-[90px]">
            <SelectGroup>
              {easeConfig?.map((el) => (
                <SelectItem key={el} value={el}>
                  {el}
                </SelectItem>
              ))}
            </SelectGroup>
          </SelectContent>
        </Select>
      );
    } else if (item.type === "color") {
      return (
        <div className="flex items-center gap-1">
          <Input
            type="color"
            className="w-[28px] p-0 px-[2px]"
            value={item?.value}
            onChange={(e) => updateProperties(e.target.value, item)}
          />
          <Input
            value={item?.value}
            onChange={(e) => updateProperties(e.target.value, item)}
            placeholder="add value"
          />
        </div>
      );
    } else {
      <></>;
    }
  };

  return (
    <div className="flex flex-col gap-2.5">
      <div className="flex justify-between items-center gap-1.5">
        <h3>Add Properties</h3>
        <div>
          <DropdownMenu>
            <DropdownMenuTrigger asChild>
              <div className="cursor-pointer flex justify-center items-center">
                <IconPlus2 size="14" />
              </div>
            </DropdownMenuTrigger>
            <DropdownMenuContent className="w-[180px]" align="end">
              <ScrollArea className="h-72">
                {properties?.map((el) => (
                  <DropdownMenuItem
                    key={el?.name}
                    onClick={() => addProperties(el)}
                  >
                    {el.name}
                  </DropdownMenuItem>
                ))}
              </ScrollArea>
            </DropdownMenuContent>
          </DropdownMenu>
        </div>
      </div>
      {selectedProperties?.length ? (
        <div className="flex flex-col gap-2">
          {selectedProperties?.map((item) => (
            <div key={item?.id}>
              {item.type === "custom" ? (
                <div className="flex justify-between items-center">
                  <div className="w-[86px] mr-2">
                    <Input
                      value={item?.name}
                      onChange={(e) =>
                        updateProperties(e.target.value, item, true)
                      }
                      placeholder="add value"
                    />
                  </div>
                  <div className="flex-1 mr-1.5">
                    <Input
                      value={item?.value}
                      onChange={(e) => updateProperties(e.target.value, item)}
                      placeholder="add value"
                    />
                  </div>
                  <div
                    className="flex justify-center items-center cursor-pointer"
                    onClick={() => deleteProperties(item?.id)}
                  >
                    <IconDelete />
                  </div>
                </div>
              ) : (
                <div className="flex justify-between items-center">
                  <div className="w-[86px] mr-2">
                    <h3 className="text-xs text-text-2 line-clamp-1 capitalize">
                      {item?.name}
                    </h3>
                  </div>
                  <div className="flex-1 mr-1.5">{generateField(item)}</div>
                  <div
                    className="flex justify-center items-center cursor-pointer"
                    onClick={() => deleteProperties(item?.id)}
                  >
                    <IconDelete />
                  </div>
                </div>
              )}
              {item?.isError && item?.errorMessage ? (
                <div className="flex justify-between mt-1">
                  <div className="w-[86px] mr-2"></div>
                  <p className="flex-1 mr-1.5 text-[11px] text-text-2 font-light">
                    {item.errorMessage}
                  </p>
                </div>
              ) : (
                ""
              )}
            </div>
          ))}
        </div>
      ) : (
        ""
      )}
      {selectedProperties?.length ? (
        <div>
          <DropdownMenu>
            <DropdownMenuTrigger asChild>
              <Button
                variant="tertiary"
                size="tertiary"
                className="[&_svg]:size-2.5"
              >
                <IconPlus className={"fill-text"} /> Add New
              </Button>
            </DropdownMenuTrigger>
            <DropdownMenuContent className="w-[180px]" align="start">
              <ScrollArea className="h-72">
                {properties?.map((el) => (
                  <DropdownMenuItem
                    key={el?.name}
                    onClick={() => addProperties(el)}
                  >
                    {el?.name}
                  </DropdownMenuItem>
                ))}
              </ScrollArea>
            </DropdownMenuContent>
          </DropdownMenu>
        </div>
      ) : (
        ""
      )}
    </div>
  );
};

export default PropertiesControl;
