import {
  Accordion2,
  AccordionContent2,
  AccordionItem2,
  AccordionTrigger2,
} from "@/components/ui/accordion2";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { AProperties, TimelineProperties } from "@/config/timelineProperties";
import { IconCopy, IconDelete } from "@/lib/icons";
import {
  Select,
  SelectContent,
  SelectGroup,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import InfoCard from "@/components/common/InfoCard";
import { Checkbox } from "@/components/ui/checkbox";
import { useState } from "react";
import PropertiesControl from "../PropertiesControl";
import { generateUniqueId } from "../../../../../utils/generateUniqueId";
import { useContentStep } from "@/hooks/app.hooks";

const AnimationItems = ({ item, timelines }) => {
  const properties = AProperties;
  const { updateAnimationData, duplicateAnimationData, deleteAnimationData } =
    useContentStep();
  const [accValue, setAccValue] = useState([""]);
  const [aTitle, setATitle] = useState(item?.title || "");
  const [aTimeline, setATimeline] = useState(item?.timeline || "");
  const [aMethod, setAMethod] = useState(item?.method || "");
  const [aProperties, setAProperties] = useState(item?.properties || []);

  const addProperties = (data) => {
    const sampleData = {
      id: generateUniqueId(),
      name: data.name || "",
      value: data.value || data?.default,
      type: data.type,
      unit: data?.unit || "",
      isError: false,
      errorMessage: "",
    };

    setAProperties((prev) => [...prev, sampleData]);
  };

  const updateProperties = (data, item, custom = false) => {
    if (item?.id) {
      const result = aProperties.map((el) => {
        if (el.id === item?.id) {
          if (custom) {
            el.name = data;
          } else {
            el.value = data;
          }
          if (el.value && el.name) {
            el.isError = false;
            el.errorMessage = "";
          } else {
            el.isError = true;
            el.errorMessage = "*required";
          }
          return el;
        } else {
          return el;
        }
      });
      setAProperties(result);
    }
  };

  const deleteProperties = (id) => {
    if (id) {
      const result = aProperties.filter((el) => el.id !== id);
      setAProperties(result);
    }
  };

  const saveAnimation = () => {
    updateAnimationData(
      {
        title: aTitle,
        timeline: aTimeline,
        method: aMethod,
        applyAnimation: {
          type: "element",
          className: "",
          applyAll: false,
        },
        properties: aProperties,
      },
      item.id
    );
  };

  return (
    <Accordion2
      type="multiple"
      value={accValue}
      onValueChange={setAccValue}
      className="w-full bg-background-hover border border-border-2 rounded"
    >
      <AccordionItem2 value="animation" className="group">
        <div className="flex justify-between items-center [&>h3]:w-full">
          <AccordionTrigger2>
            <p>{aTitle}</p>
          </AccordionTrigger2>
          <div className="w-[54px]">
            <div className="hidden group-hover:flex justify-center items-center">
              <div
                className="py-2.5 ps-2 pe-[7px] flex justify-center items-center cursor-pointer"
                onClick={() => duplicateAnimationData(item.id)}
              >
                <IconCopy />
              </div>
              <div
                className="py-2.5 pe-2 ps-[7px] flex justify-center items-center cursor-pointer"
                onClick={() => deleteAnimationData(item.id)}
              >
                <IconDelete />
              </div>
            </div>
          </div>
        </div>
        <AccordionContent2 className="px-2 py-2.5 border-t border-border-2">
          <div>
            <div className="pb-2.5 border-b border-border-2 flex flex-col gap-2.5">
              <div className="flex justify-between items-center gap-2">
                <div className="w-[70px]">
                  <h3 className="text-xs text-text">Title</h3>
                </div>
                <div className="flex-1">
                  <Input
                    value={aTitle}
                    onChange={(e) => setATitle(e.target.value)}
                    placeholder="Animation _1"
                    className="h-[28px]"
                  />
                </div>
              </div>
              <div className="flex justify-between items-center gap-2">
                <div className="w-[70px]">
                  <h3 className="text-xs text-text">Timeline</h3>
                </div>
                <div className="flex-1">
                  <Select value={aTimeline} onValueChange={setATimeline}>
                    <SelectTrigger>
                      <SelectValue placeholder="Select a timeline" />
                    </SelectTrigger>
                    {timelines?.length ? (
                      <SelectContent>
                        <SelectGroup>
                          {timelines.map((item) => (
                            <SelectItem key={item.id} value={item.title}>
                              {item.title}
                            </SelectItem>
                          ))}
                        </SelectGroup>
                      </SelectContent>
                    ) : (
                      ""
                    )}
                  </Select>
                </div>
              </div>
              <div className="flex justify-between items-center gap-2">
                <div className="w-[70px]">
                  <h3 className="text-xs text-text">Method</h3>
                </div>
                <div className="flex-1">
                  <Select value={aMethod} onValueChange={setAMethod}>
                    <SelectTrigger>
                      <SelectValue placeholder="Select method" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectGroup>
                        <SelectItem value="to">To</SelectItem>
                        <SelectItem value="from">From</SelectItem>
                        <SelectItem value="fromTo">From To</SelectItem>
                        <SelectItem value="set">Set</SelectItem>
                      </SelectGroup>
                    </SelectContent>
                  </Select>
                </div>
              </div>
            </div>

            {/* apply animation  */}
            <div className="py-2.5 border-b border-border-2 flex flex-col gap-2.5">
              <div>
                <h3 className="text-text-2 mb-1.5">Applies on</h3>
                <div>
                  <Tabs defaultValue="Element">
                    <TabsList className="grid w-full grid-cols-2">
                      <TabsTrigger value="Element">Element</TabsTrigger>
                      <TabsTrigger value="Class">Class</TabsTrigger>
                    </TabsList>
                    <TabsContent value="Element">
                      <InfoCard />
                    </TabsContent>
                    <TabsContent value="Class">
                      <div className="flex flex-col gap-2.5">
                        <div className="flex justify-between items-center gap-2">
                          <div className="w-[70px]">
                            <h3 className="text-xs text-text-2">Class</h3>
                          </div>
                          <div className="flex-1">
                            <Input
                              placeholder="<h1 - heading>"
                              className="h-[28px] bg-background-hover text-text-2"
                            />
                          </div>
                        </div>
                        <div className="flex items-center space-x-1">
                          <Checkbox id="terms" />
                          <label
                            htmlFor="terms"
                            className="text-[11.5px] leading-[1.13] text-text-3 peer-disabled:cursor-not-allowed peer-disabled:opacity-70"
                          >
                            Applies to all similar classes
                          </label>
                        </div>
                      </div>
                    </TabsContent>
                  </Tabs>
                </div>
              </div>
            </div>

            {/* properties  */}
            <div className="py-2.5 border-b border-border-2">
              <PropertiesControl
                properties={properties}
                selectedProperties={aProperties}
                addProperties={addProperties}
                updateProperties={updateProperties}
                deleteProperties={deleteProperties}
              />
            </div>
            <div className="flex justify-end items-center gap-1.5 pt-2.5">
              <Button variant="secondary" onClick={() => setAccValue([""])}>
                Close
              </Button>
              <Button onClick={() => saveAnimation()}>Save</Button>
            </div>
          </div>
        </AccordionContent2>
      </AccordionItem2>
    </Accordion2>
  );
};

export default AnimationItems;
