import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from "@/components/ui/accordion";
import {
  Select,
  SelectContent,
  SelectGroup,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { Label } from "@/components/ui/label";
import { Switch } from "@/components/ui/switch";
import { useState } from "react";
import { Input } from "@/components/ui/input";
import { TimelineProperties } from "@/config/timelineProperties";
import PropertiesControl from "../PropertiesControl";

const EditorScrollTrigger = () => {
  const properties = TimelineProperties;
  const [enableTrigger, setEnableTrigger] = useState(false);
  return (
    <Accordion type="single" collapsible className="w-full p-3">
      <AccordionItem value="item-1">
        <AccordionTrigger>ScrollTrigger</AccordionTrigger>
        <AccordionContent className="pb-0 mt-5 flex flex-col gap-4">
          <div className="flex items-center justify-between gap-2 mt-2">
            <Label htmlFor="scrollTrigger-enable">Enable ScrollTrigger</Label>
            <Switch
              id="scrollTrigger-enable"
              checked={enableTrigger}
              onCheckedChange={setEnableTrigger}
            />
          </div>
          {enableTrigger ? (
            <>
              <div>
                {/* select timeline */}
                <div className="flex justify-between items-center gap-2 pb-2.5 border-b border-border-2">
                  <div className="w-[70px]">
                    <h3 className="text-xs text-text">Timeline</h3>
                  </div>
                  <div className="flex-1">
                    <Select>
                      <SelectTrigger>
                        <SelectValue placeholder="Select a timeline" />
                      </SelectTrigger>
                      <SelectContent>
                        <SelectGroup>
                          <SelectItem value="Timeline _1">
                            Timeline _1
                          </SelectItem>
                          <SelectItem value="Timeline _2">
                            Timeline _2
                          </SelectItem>
                        </SelectGroup>
                      </SelectContent>
                    </Select>
                  </div>
                </div>
                {/* trigger and endTrigger */}
                <div className="flex flex-col gap-2.5 py-2.5 border-b border-border-2">
                  <div className="flex justify-between items-center gap-2">
                    <div className="w-[70px]">
                      <h3 className="text-xs text-text">Trigger</h3>
                    </div>
                    <div className="flex-1">
                      <Input placeholder=".start_trigger" />
                    </div>
                  </div>
                  <div className="flex justify-between items-center gap-2">
                    <div className="w-[70px]">
                      <h3 className="text-xs text-text">End Trigger</h3>
                    </div>
                    <div className="flex-1">
                      <Input placeholder=".end_trigger" />
                    </div>
                  </div>
                </div>
                {/* start and end */}
                <div className="py-2.5 border-b border-border-2 flex flex-col gap-2.5">
                  <div className="flex justify-between items-center gap-2">
                    <div className="w-[70px]">
                      <h3 className="text-xs text-text">Start</h3>
                    </div>
                    <div className="flex-1">
                      <Select>
                        <SelectTrigger>
                          <SelectValue placeholder="Select Start" />
                        </SelectTrigger>
                        <SelectContent>
                          <SelectGroup>
                            <SelectItem value="Top Top">Top Top</SelectItem>
                            <SelectItem value="Top Center">
                              Top Center
                            </SelectItem>
                            <SelectItem value="Top Bottom">
                              Top Bottom
                            </SelectItem>
                            <SelectItem value="Bottom Top">
                              Bottom Top
                            </SelectItem>
                            <SelectItem value="Bottom Center">
                              Bottom Center
                            </SelectItem>
                            <SelectItem value="Bottom Bottom">
                              Bottom Bottom
                            </SelectItem>
                            <SelectItem value="Custom">Custom</SelectItem>
                          </SelectGroup>
                        </SelectContent>
                      </Select>
                    </div>
                  </div>
                  <div className="flex justify-between items-center gap-2">
                    <div className="w-[70px]">
                      <h3 className="text-xs text-text">End</h3>
                    </div>
                    <div className="flex-1">
                      <Select>
                        <SelectTrigger>
                          <SelectValue placeholder="Select End" />
                        </SelectTrigger>
                        <SelectContent>
                          <SelectGroup>
                            <SelectItem value="Top Top">Top Top</SelectItem>
                            <SelectItem value="Top Center">
                              Top Center
                            </SelectItem>
                            <SelectItem value="Top Bottom">
                              Top Bottom
                            </SelectItem>
                            <SelectItem value="Bottom Top">
                              Bottom Top
                            </SelectItem>
                            <SelectItem value="Bottom Center">
                              Bottom Center
                            </SelectItem>
                            <SelectItem value="Bottom Bottom">
                              Bottom Bottom
                            </SelectItem>
                            <SelectItem value="Custom">Custom</SelectItem>
                          </SelectGroup>
                        </SelectContent>
                      </Select>
                    </div>
                  </div>
                </div>

                {/* scrub, pin and markers  */}
                <div className="py-2.5 border-b border-border-2 flex flex-col gap-2.5">
                  <div className="flex justify-between items-center gap-2">
                    <div className="w-[70px]">
                      <h3 className="text-xs text-text">Scrub</h3>
                    </div>
                    <div className="flex-1">
                      <Select>
                        <SelectTrigger>
                          <SelectValue placeholder="Select Scrub" />
                        </SelectTrigger>
                        <SelectContent>
                          <SelectGroup>
                            <SelectItem value="True">True</SelectItem>
                            <SelectItem value="False">False</SelectItem>
                          </SelectGroup>
                        </SelectContent>
                      </Select>
                    </div>
                  </div>
                  <div className="flex justify-between items-center gap-2">
                    <div className="w-[70px]">
                      <h3 className="text-xs text-text">Pin</h3>
                    </div>
                    <div className="flex-1">
                      <Select>
                        <SelectTrigger>
                          <SelectValue placeholder="Select Pin" />
                        </SelectTrigger>
                        <SelectContent>
                          <SelectGroup>
                            <SelectItem value="True">True</SelectItem>
                            <SelectItem value="False">False</SelectItem>
                          </SelectGroup>
                        </SelectContent>
                      </Select>
                    </div>
                  </div>
                  <div className="flex justify-between items-center gap-2">
                    <div className="w-[70px]">
                      <h3 className="text-xs text-text">Markers</h3>
                    </div>
                    <div className="flex-1">
                      <Select>
                        <SelectTrigger>
                          <SelectValue placeholder="Select Markers" />
                        </SelectTrigger>
                        <SelectContent>
                          <SelectGroup>
                            <SelectItem value="True">True</SelectItem>
                            <SelectItem value="False">False</SelectItem>
                          </SelectGroup>
                        </SelectContent>
                      </Select>
                    </div>
                  </div>
                </div>
              </div>

              {/* properties  */}
              <div className="pb-2.5">
                <PropertiesControl properties={properties} />
              </div>
            </>
          ) : (
            ""
          )}
        </AccordionContent>
      </AccordionItem>
    </Accordion>
  );
};

export default EditorScrollTrigger;
